var _excluded = ["value", "onFocus", "onBlur", "showErrorMessage", "error", "style", "className", "password", "email"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState, useCallback } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Input from './TextInputComponent';
import WithError from './WithError';
import { onBlurForReduxForm } from './utility/redux-form';

function TextInput(_ref, ref) {
  var value = _ref.value,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      showErrorMessage = _ref.showErrorMessage,
      error = _ref.error,
      style = _ref.style,
      className = _ref.className,
      password = _ref.password,
      email = _ref.email,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      isFocused = _useState2[0],
      setFocused = _useState2[1];

  var _onFocus = useCallback(function (event) {
    if (onFocus) {
      onFocus(event);
    }

    setFocused(true);
  }, [onFocus, setFocused]);

  var _onBlur = useCallback(function (event) {
    if (onBlur) {
      onBlurForReduxForm(onBlur, event, value);
    }

    setFocused(false);
  }, [onBlur, setFocused, value]); // Deprecated.
  // Use `type="password"` instead.


  if (password) {
    rest.type = 'password';
  } // Deprecated.
  // Use `type="email"` instead.


  if (email) {
    rest.type = 'email';
  }

  return /*#__PURE__*/React.createElement(WithError, {
    error: showErrorMessage ? error : undefined,
    style: style,
    className: classNames(className, 'rrui__text-input', {
      'rrui__text-input--focus': isFocused
    })
  }, /*#__PURE__*/React.createElement(Input, _extends({}, rest, {
    ref: ref,
    value: value,
    error: error,
    onFocus: _onFocus,
    onBlur: _onBlur
  })));
}

TextInput = /*#__PURE__*/React.forwardRef(TextInput);
TextInput.propTypes = {
  // Text field label
  label: PropTypes.string,
  // HTML form input `name` attribute
  name: PropTypes.string,
  // Text field value
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  // Is called when the `value` is edited
  onChange: PropTypes.func.isRequired,
  // A custom input component.
  inputComponent: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  // Indicates that the input is invalid.
  error: PropTypes.oneOfType([PropTypes.string, PropTypes.bool]),
  // If this flag is `true` then the `error` is shown (if passed).
  // If this flag is `false` then the `error` is not shown (even if passed).
  showErrorMessage: PropTypes.bool,
  // Set to `true` to mark the field as required
  required: PropTypes.bool,
  // `<input/>` placeholder
  placeholder: PropTypes.string,
  // `<textarea/>` instead of an `<input type="text"/>`
  multiline: PropTypes.bool,
  // Autoresize state saving/restoring for a `multiline` text input:
  initialHeight: PropTypes.number,
  onHeightChange: PropTypes.func,
  // Deprecated.
  // Use `type="email"` instead.
  // Sets HTML input `type` attribute to `email`
  email: PropTypes.bool,
  // Deprecated.
  // Use `type="password"` instead.
  // Sets HTML input `type` attribute to `password`
  password: PropTypes.bool,
  // Autofocuses the input field.
  // Deprecated. Use `autoFocus` instead.
  focus: PropTypes.bool,
  // HTML `tabindex` attribute
  tabIndex: PropTypes.number,
  // `<textarea/>` `rows` attribute (row count, i.e. height)
  rows: PropTypes.number,
  // `<textarea/>` `cols` attribute (column count, i.e. width)
  cols: PropTypes.number,
  // Is called when the input is focused
  onFocus: PropTypes.func,
  // `onKeyDown` event handler
  onKeyDown: PropTypes.func,
  // Is called when the input is blurred
  onBlur: PropTypes.func,
  // Is called when the input is clicked
  onClick: PropTypes.func,
  // CSS style object
  style: PropTypes.object,
  // CSS name
  className: PropTypes.string,
  // CSS style object for `<input/>`
  inputStyle: PropTypes.object
};
TextInput.defaultProps = {
  // Show `error` (if passed).
  showErrorMessage: true
};
export default TextInput;
//# sourceMappingURL=TextInput.js.map